==> dobroparser-0.1.1b.tar.gz: DobrochanParser/tnotifywindow.cpp <==
#include "tnotifywindow.h"

TNotifyWindow::TNotifyWindow(QString Title, QString Text, int pos, QWidget *parent) :
    QWidget (parent),
    thisObject (this),
    message (new QLabel(this)),
    desktop (QApplication::desktop()),
    timer (new QTimer()),
    toolBarHeight (55)
{
    this->setWindowFlags(Qt::ToolTip | // This type flag is the second point
                           Qt::FramelessWindowHint |
                           Qt::WindowSystemMenuHint |
                           Qt::WindowStaysOnTopHint |
                           Qt::X11BypassWindowManagerHint);

    //this->setAttribute(Qt::WA_NoBackground);
    this->setAttribute(Qt::WA_TranslucentBackground);
    //this->setAttribute( Qt::WA_NoSystemBackground, true);
    Text.insert(0, "<font color=white>");
    Text.append("</font>");
    message->setStyleSheet( "QLabel {padding: 3px; padding-left: 20px; padding-right: 20px; margin: 2x; border: 0px solid black; border-radius: 20px; background-color: rgba(0%,0%,0%,80%);}" );
    message->setText(Text);
    message->setMinimumWidth(200);
    message->setMaximumWidth(325);
    message->setMinimumHeight(150);
    message->setMaximumHeight(150);
    timer->setSingleShot(true);
    timer->setInterval(5000);
    timer->start();
    QObject::connect(timer, SIGNAL(timeout()), this, SLOT(sendRequestDelete()));
    message->show();
    this->resize(message->size());
    this->move(desktop->width()-this->width(), desktop->height()-this->height()*(pos+1)-toolBarHeight);
    this->show();
}

void TNotifyWindow::sendRequestDelete(void){
    emit requestDelete(thisObject);
}

==> dobroparser-0.1.2.tar.gz: DobrochanParser/tnotifywindow.cpp <==
#include "tnotifywindow.h"

TNotifyWindow::TNotifyWindow(QString Title, QString Text, int pos, QWidget *parent) :
    QWidget (parent),
    thisObject (this),
    message (new QLabel(this)),
    desktop (QApplication::desktop()),
    timer (new QTimer()),
    toolBarHeight (55)
{
    this->setWindowFlags(Qt::ToolTip | // This type flag is the second point
                           Qt::FramelessWindowHint |
                           Qt::WindowSystemMenuHint |
                           Qt::WindowStaysOnTopHint |
                           Qt::X11BypassWindowManagerHint);

    //this->setAttribute(Qt::WA_NoBackground);
    this->setAttribute(Qt::WA_TranslucentBackground);
    //this->setAttribute( Qt::WA_NoSystemBackground, true);
    QRegExp newLineExp("\\n");

    //Editing title
    QFontMetrics fm(message->font());
    Title = fm.elidedText(Title,Qt::ElideRight,300);
    Title.insert(0,"<b>");
    Title.append("</b><br>");

    Text.replace(newLineExp, "<br>");
    Text.insert(0, QString("<font color=white>").append(Title));
    Text.append("</font>");
    message->setStyleSheet( "QLabel {padding: 3px; padding-left: 20px; padding-right: 20px; margin: 2x; border: 0px solid black; border-radius: 20px; background-color: rgba(0%,0%,0%,80%);}" );
    message->setMinimumWidth(200);
    message->setMaximumWidth(325);
    message->setMinimumHeight(40);
    message->setMaximumHeight(150);
    message->setWordWrap(true);
    message->setText(Text);
    message->adjustSize();
    timer->setSingleShot(true);
    timer->setInterval(10000);
    timer->start();
    QObject::connect(timer, SIGNAL(timeout()), this, SLOT(sendRequestDelete()));
    message->show();
    this->resize(message->size());

    this->move(desktop->width(), desktop->height()-this->height()*(pos+1)-toolBarHeight);

    this->show();
}

void TNotifyWindow::sendRequestDelete(void){
    emit requestDelete(thisObject);
}

void TNotifyWindow::showEvent(QShowEvent * event){
    QPropertyAnimation* anima = new QPropertyAnimation(this, "geometry");
    anima->setDuration(300);
    anima->setStartValue(this->geometry());
    anima->setEndValue(QRect(desktop->width()-this->width(),this->y(),  this->width(), this->height()));
    anima->start();
}
